---
layout: article
title:  "The <code>snips</code> Object"
permalink: /articles/snips-object/
toc: Introduction|Available fields
---

## Introduction

The Snipsfile can be used to declare how your assistant should react to intents. More precisely, upon receiving an intent, the Snipsfile can tell the assistant to execute a specific peice of code, for instance to turn up a light using the Philips Hue API, or to play some music on a Sonos speaker.

These bindings are declared in a section of the Snipsfile named `skills`. It can look like the following:

```yaml
skills:
  - url: github.com/snipsco/snips-skill-hue
    intents:
      - intent: LightsOn
        action: "turn_on"
      - intent: SetLightColor
        action: |
          {% raw %}{%{% endraw %}
          if snips.intent.objectColor != None:
            snips.skill.set_color_name(snips.intent.objectColor)
          else:
            snips.dialogue.speak("You did not provide a color")
          {% raw %}%}{% endraw %}
```

Here, the skill is an external Python module found on a public Github repository (it can also be entirely specified in the Snipsfile, without reference to an external Python module, cf. the [Calculator example]({{ site.baseurl }}/tutorials/calculator)) example).

In order to access the intent and related slots on one hand, and trigger actions on the skill on the other, a special object named `snips` is provided. It contains the following fields.

## Available fields

### snips.intent

This object encapsulates your intent, and gives you access to slots values.

### snips.skill

When your skill is an external Python module, it will be instantiated at runtime and encapsulated in a `snips.skill` object. For instance, if your skill exposes a method `set_color_name()`, you can call it using `snips.skill.set_color_name()`.

### snips.dialogue, snips.site_id and snips.session_id

The `snips.dialogue` object allows you to easily get access to Text-To-Speech functionality, via a function `snips.dialogue.speak()`. You may call it with a string:

```python
snips.dialogue.speak("OK, turning on the lights")
```

or with an additional parameter specifying the site id, used for instance in a multi-room set up:

```python
snips.dialogue.speak("OK, turning on the lights", snips.session_id, snips.site_id)
```

For more information on multi-room and dialog, see the [Building Rich Interactions](https://github.com/snipsco/snips-platform-documentation/wiki/5.-Build-rich-interactions) article.
