"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const cli_1 = require("../cli");
const config_1 = require("../utils/config");
const ssh_1 = require("../session/ssh");
exports.command = 'connect <HOSTNAME_OR_IP>';
exports.desc = 'Connect to a device';
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const hostname = argv['HOSTNAME_OR_IP'];
    let username = '';
    let password = '';
    try {
        const response = yield cli_1.default.prompt.promptQuestions([config_1.Config.usernameQuestion, config_1.Config.passwordQuestion]);
        username = response['username'];
        password = response['password'];
    }
    catch (e) {
        cli_1.default.stream.println();
        cli_1.default.stream.error(`Error connecting to device: ${e.message}`, true);
        process.exit();
    }
    if (password.length === 0) {
        cli_1.default.stream.error('Password cannot be blank');
        process.exit();
    }
    const onConnected = () => {
        cli_1.default.stream.stopAndClear();
        cli_1.default.stream.success(`Connected to ${hostname}`, true);
    };
    const onSSHCopyId = () => {
        cli_1.default.stream.hint(`A public key has been generated and copied to the device at ${hostname}:${ssh_1.snipsRemoteAuthorizedKeysFilename}`);
    };
    const onCredentialsSaved = () => { };
    const ssh = new ssh_1.SSHService();
    let error = false;
    cli_1.default.stream.loading(`Connecting to ${hostname}`);
    let initialError = undefined;
    yield ssh.newConnection({ hostname, username }, password, onConnected, onSSHCopyId, onCredentialsSaved).catch(e => {
        error = true;
        initialError = e.message;
    });
    if (error) {
        yield ssh.newConnection({ username, hostname: hostname + '.local' }, password, onConnected, onSSHCopyId, onCredentialsSaved)
            .catch(e => {
            cli_1.default.stream.stopAndClear();
            cli_1.default.stream.println();
            cli_1.default.stream.error((initialError !== undefined) ? initialError : e.message, true);
            process.exit();
        });
    }
    ssh.disconnect();
    process.exit();
});
