"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const cli_1 = require("../cli");
const chalk_1 = require("chalk");
const promises_1 = require("../utils/promises");
const rp = require('request-promise');
const fs = require('fs-extra');
exports.command = 'create';
exports.desc = 'Create a new Snips assistant';
const snipsfileSampleLocation = 'https://github.com/snipsco/demo-assistants/raw/master/Snipsfiles/Snipsfile.weather';
const fallbackSnipsfile = `
assistant_url: https://github.com/snipsco/demo-assistants/raw/master/assistants/weather.zip
skills:
  - url: https://github.com/snipsco/snips-skill-owm
    package_name: snipsowm
    class_name: SnipsOWM
    params:
        default_location: "Paris, fr"
        api_key: a322f5315d6afa31628c1384e389ffc3
`;
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    cli_1.cli.stream.loading('Creating new Snipsfile...');
    yield promises_1.timeout(1000);
    let snipsfile;
    try {
        snipsfile = yield rp(snipsfileSampleLocation);
    }
    catch (e) {
        snipsfile = fallbackSnipsfile;
    }
    try {
        yield fs.outputFile('Snipsfile', snipsfile.trim());
    }
    catch (e) {
        cli_1.cli.stream.stopAndClear();
        cli_1.cli.stream.error('Error creating Snipsfile. Make sure you have write access to the current working directory', true);
        process.exit();
    }
    cli_1.cli.stream.done();
    cli_1.cli.stream.loading(`Loading sample Snipsfile at ${process.cwd()}/Snipsfile...`);
    yield promises_1.timeout(1000);
    cli_1.cli.stream.done();
    cli_1.cli.stream.success('Snipsfile created');
    cli_1.cli.stream.hint(`You can now deploy the assistant to your device using ${chalk_1.default.blue('sam deploy')}`);
});
