"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const chalk_1 = require("chalk");
const cli_1 = require("../cli");
const ssh_1 = require("../session/ssh");
const promises_1 = require("../utils/promises");
exports.command = 'init';
exports.desc = 'Install Snips Platform components';
exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
};
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const verbose = JSON.parse(JSON.stringify(argv)).verbose;
    cli_1.default.stream.loading('Installing Snips Platform components. This may take a few minutes...');
    const ssh = new ssh_1.SSHService();
    yield ssh.connect().catch(e => {
        cli_1.default.stream.stop();
        cli_1.default.stream.error(e);
        process.exit();
    });
    yield promises_1.timeout(500);
    let didStopLoading = false;
    try {
        yield ssh.installSnips(logMessage => {
            if (verbose) {
                if (!didStopLoading) {
                    cli_1.default.stream.stop();
                    didStopLoading = true;
                }
                cli_1.default.stream.print(logMessage);
            }
        });
    }
    catch (e) {
        cli_1.default.stream.error('Failed to install platform: ' + e.stack);
        ssh.disconnect();
        process.exit();
    }
    ssh.disconnect();
    cli_1.default.stream.success('Successfully installed the Snips Platform');
    cli_1.default.stream.hint('You can now setup your audio with ' + chalk_1.default.blue('sam setup audio'));
});
