"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_1 = require("../cli");
const ssh_1 = require("../session/ssh");
const chalk_1 = require("chalk");
exports.command = 'install <assistant_path>';
exports.desc = 'Install an assistant to the device';
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const assistantPath = JSON.parse(JSON.stringify(argv)).assistant_path;
    const ssh = new ssh_1.SSHService();
    yield ssh.connect()
        .catch(e => {
        cli_1.cli.stream.error(e);
        process.exit();
    });
    cli_1.cli.stream.loading(`Deploying assistant to ${ssh.credentials.hostname}...`);
    yield ssh.installAssistant(assistantPath)
        .catch(e => {
        cli_1.cli.stream.error('Unable to install the assistant:' + e.message);
        ssh.disconnect();
        process.exit();
    });
    cli_1.cli.stream.success();
    const assistant = yield ssh.getInstalledAssistant();
    if (assistant !== undefined) {
        cli_1.cli.stream.success(`Snips assistant is now running. Say ${chalk_1.default.blue(assistant.hotword)} to start!`);
    }
    else {
        cli_1.cli.stream.success(`Snips assistant is now running`);
    }
    ssh.disconnect();
    process.exit();
});
