"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_1 = require("../cli");
const ssh_1 = require("../session/ssh");
exports.command = 'log [services...]';
exports.desc = 'Display Snips Services logs';
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    let services = JSON.parse(JSON.stringify(argv)).services;
    const ssh = new ssh_1.SSHService();
    yield ssh.connect()
        .catch(e => {
        cli_1.cli.stream.error(e);
        process.exit();
    });
    if (services !== undefined) {
        services = services.filter(service => {
            const isSnipsService = ssh_1.availableSnipsServices.includes(service);
            if (isSnipsService === false) {
                cli_1.cli.stream.error(`Unknown service ${service}, removing from the list`);
            }
            return isSnipsService;
        });
    }
    yield ssh.journalctlLogs(services, response => cli_1.cli.stream.print(response))
        .catch(e => cli_1.cli.stream.error(e));
    ssh.disconnect();
});
