"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_1 = require("../cli");
const ssh_1 = require("../session/ssh");
exports.command = 'reboot';
exports.desc = 'Reboot the device';
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const ssh = new ssh_1.SSHService();
    yield ssh.connect()
        .catch(e => {
        cli_1.cli.stream.error(e);
        process.exit();
    });
    yield ssh.reboot().catch(_ => { });
    let loadingText = 'Waiting for device to reboot';
    cli_1.cli.stream.loading(loadingText);
    yield ssh.retryConnect(() => {
        loadingText += ' . ';
        cli_1.cli.stream.update(loadingText);
    })
        .then(isConnected => {
        if (isConnected) {
            cli_1.cli.stream.done();
            cli_1.cli.stream.success('Device has rebooted');
        }
        else {
            cli_1.cli.stream.error('Failed to reconnect, try a hard reboot');
        }
    });
    ssh.disconnect();
    process.exit();
});
