"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs = require('fs-extra');
const os = require('os');
const path = require("path");
const samConfigDirectory = path.join(os.homedir(), '.sam');
const saveCredentialsFile = 'snips-device-credentials.json';
exports.localConfigurationFile = path.join(samConfigDirectory, saveCredentialsFile);
class Config {
}
Config.getCredentials = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    return fs.ensureDir(samConfigDirectory)
        .then(_ => fs.stat(exports.localConfigurationFile))
        .then(_ => Config.readCredentialsOnDisk())
        .then(credentials => credentials)
        .catch(_ => {
        throw new Error('No credentials found on disk');
    });
});
Config.deleteCredentials = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    return yield fs.remove(exports.localConfigurationFile);
});
Config.saveCredentialsOnDisk = (credentials) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    return fs.outputFile(exports.localConfigurationFile, JSON.stringify(credentials));
});
Config.readCredentialsOnDisk = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    try {
        const credentials = yield fs.readJson(exports.localConfigurationFile);
        return credentials;
    }
    catch (e) {
        throw new Error('Credentials not found');
    }
});
Config.hostnameQuestion = [
    {
        name: 'hostname',
        type: 'input',
        default: 'hostname.local',
        message: 'Enter your device hostname or IP:',
        validate: value => {
            if (value.length)
                return true;
            return 'Hostname cannot be blank';
        },
    },
];
Config.usernameQuestion = [
    {
        name: 'username',
        type: 'username',
        default: 'pi',
        message: 'Enter username for the device:',
        validate: value => {
            if (value.length)
                return true;
            return 'Username cannot be blank';
        },
    },
];
Config.passwordQuestion = [
    {
        name: 'password',
        type: 'password',
        default: 'raspberry',
        message: 'Enter password for the device:',
        validate: value => {
            if (value.length)
                return true;
            return 'Password cannot be blank';
        },
    },
];
exports.Config = Config;
