import * as process from 'process';
import * as yargs from 'yargs';
import { cli } from '../cli';
import chalk from 'chalk';
import { timeout } from '../utils/promises';

const rp = require('request-promise');
const fs = require('fs-extra');

exports.command = 'create';
exports.desc = 'Create a new Snips assistant';

const snipsfileSampleLocation = 'https://github.com/snipsco/demo-assistants/raw/master/Snipsfiles/Snipsfile.weather';

const fallbackSnipsfile = `
assistant_url: https://github.com/snipsco/demo-assistants/raw/master/assistants/weather.zip
skills:
  - url: https://github.com/snipsco/snips-skill-owm
    package_name: snipsowm
    class_name: SnipsOWM
    params:
        default_location: "Paris, fr"
        api_key: a322f5315d6afa31628c1384e389ffc3
`;

exports.handler = async (argv: yargs.Argv) => {
    cli.stream.loading('Creating new Snipsfile...');
    await timeout(1000);

    let snipsfile;
    try {
        snipsfile = await rp(snipsfileSampleLocation);
    } catch (e) {
        snipsfile = fallbackSnipsfile;
    }

    try {
        await fs.outputFile('Snipsfile', snipsfile.trim());
    } catch (e) {
        cli.stream.stopAndClear();
        cli.stream.error('Error creating Snipsfile. Make sure you have write access to the current working directory', true);
        process.exit();
    }

    cli.stream.done();
    cli.stream.loading(`Loading sample Snipsfile at ${process.cwd()}/Snipsfile...`);
    await timeout(1000);
    cli.stream.done();
    cli.stream.success('Snipsfile created');
    cli.stream.hint(`You can now deploy the assistant to your device using ${chalk.blue('sam deploy')}`);
};
