import * as yargs from 'yargs';
import { cli } from '../cli';
import { SSHService, availableSnipsServices } from '../session/ssh';

exports.command = 'log [services...]';
exports.desc = 'Display Snips Services logs';

exports.handler = async (argv: yargs.Argv) => {
    let services: string[] | undefined = JSON.parse(JSON.stringify(argv)).services;
    const ssh = new SSHService();
    await ssh.connect()
    .catch(e => {
        cli.stream.error(e);
        process.exit();
    });

    if (services !== undefined) {
        services = services.filter(service => {
            const isSnipsService = availableSnipsServices.includes(service);
            if (isSnipsService === false) {
                cli.stream.error(`Unknown service ${service}, removing from the list`);
            }
            return isSnipsService;
        });
    }

    await ssh.journalctlLogs(services, response => cli.stream.print(response))
    .catch(e => cli.stream.error(e));
    ssh.disconnect();
};
